==> linshare-1.4.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/DomainPolicyFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2013 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2013. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import java.util.ArrayList;
import java.util.List;

import org.linagora.linshare.core.domain.entities.DomainPolicy;
import org.linagora.linshare.core.domain.entities.Role;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.DomainPolicyFacade;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.DomainPolicyService;
import org.linagora.linshare.webservice.dto.DomainPolicyDto;

public class DomainPolicyFacadeImpl extends AdminGenericFacadeImpl implements DomainPolicyFacade {

	private final DomainPolicyService domainPolicyService;
	

	public DomainPolicyFacadeImpl(final AccountService accountService, final DomainPolicyService domainPolicyService) {
		super(accountService);
		this.domainPolicyService = domainPolicyService;
	}

	@Override
	public List<DomainPolicyDto> getDomainPolicies() throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		ArrayList<DomainPolicyDto> domainPolicies = new ArrayList<DomainPolicyDto>();
		for (DomainPolicy domainPolicy : domainPolicyService.findAllDomainPolicy()) {
			domainPolicies.add(new DomainPolicyDto(domainPolicy));
		}
		return domainPolicies;
	}
}

==> linshare-1.5.6-src.tar.bz2: src/main/java/org/linagora/linshare/core/facade/webservice/admin/impl/DomainPolicyFacadeImpl.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.facade.webservice.admin.impl;

import java.util.ArrayList;
import java.util.List;

import org.linagora.linshare.core.domain.entities.DomainPolicy;
import org.linagora.linshare.core.domain.entities.Role;
import org.linagora.linshare.core.exception.BusinessException;
import org.linagora.linshare.core.facade.webservice.admin.DomainPolicyFacade;
import org.linagora.linshare.core.service.AccountService;
import org.linagora.linshare.core.service.DomainPolicyService;
import org.linagora.linshare.webservice.dto.DomainPolicyDto;

public class DomainPolicyFacadeImpl extends AdminGenericFacadeImpl implements
		DomainPolicyFacade {

	private final DomainPolicyService domainPolicyService;

	public DomainPolicyFacadeImpl(final AccountService accountService,
			final DomainPolicyService domainPolicyService) {
		super(accountService);
		this.domainPolicyService = domainPolicyService;
	}

	@Override
	public DomainPolicyDto get(String identifier) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		return new DomainPolicyDto(domainPolicyService.retrieveDomainPolicy(identifier));
	}

	@Override
	public List<DomainPolicyDto> getAll() throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
        ArrayList<DomainPolicyDto> domainPolicies = new ArrayList<DomainPolicyDto>();
        for (DomainPolicy domainPolicy : domainPolicyService.findAllDomainPolicy()) {
            domainPolicies.add(new DomainPolicyDto(domainPolicy));
        }
        return domainPolicies;
    }

	@Override
	public void create(DomainPolicyDto policy) throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		domainPolicyService.createDomainPolicy(domainPolicyService.transform(policy));
	}

	@Override
	public void update(DomainPolicyDto policy)
			throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		domainPolicyService.updateDomainPolicy(domainPolicyService.transform(policy));
	}

	@Override
	public void delete(String identifier)
			throws BusinessException {
		checkAuthentication(Role.SUPERADMIN);
		domainPolicyService.deletePolicy(identifier);
	}
}
